document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu toggle
  const menuToggle = document.querySelector('.menu-toggle');
  const navLinks = document.querySelector('.nav-links');
  
  menuToggle.addEventListener('click', () => {
    navLinks.classList.toggle('active');
  });

  // Timer functionality
  let timerInterval;
  let seconds = 0;
  let isRunning = false;
  
  const timerDisplay = document.getElementById('timer-display');
  const timerToggle = document.getElementById('timer-toggle');
  const timerReset = document.getElementById('timer-reset');

  function formatTime(totalSeconds) {
    const hours = Math.floor(totalSeconds / 3600);
    const minutes = Math.floor((totalSeconds % 3600) / 60);
    const seconds = totalSeconds % 60;
    return `${String(hours).padStart(2, '0')}:${String(minutes).padStart(2, '0')}:${String(seconds).padStart(2, '0')}`;
  }

  function updateTimer() {
    seconds++;
    timerDisplay.textContent = formatTime(seconds);
  }

  timerToggle.addEventListener('click', () => {
    if (isRunning) {
      clearInterval(timerInterval);
      timerToggle.textContent = 'Start';
    } else {
      timerInterval = setInterval(updateTimer, 1000);
      timerToggle.textContent = 'Pause';
    }
    isRunning = !isRunning;
  });

  timerReset.addEventListener('click', () => {
    clearInterval(timerInterval);
    seconds = 0;
    timerDisplay.textContent = formatTime(seconds);
    timerToggle.textContent = 'Start';
    isRunning = false;
  });

  // Task form handling
  const taskForm = document.getElementById('task-form');
  const taskContainer = document.querySelector('.task-container');

  taskForm.addEventListener('submit', (e) => {
    e.preventDefault();
    const taskName = document.getElementById('task-name').value;
    const taskCategory = document.getElementById('task-category').value;
    const taskPriority = document.getElementById('task-priority').value;
    const taskDescription = document.getElementById('task-description').value;

    const taskElement = document.createElement('div');
    taskElement.classList.add('task-item');
    taskElement.innerHTML = `
      <h3>${taskName}</h3>
      <p>${taskDescription}</p>
      <div class="task-meta">
        <span class="category">${taskCategory}</span>
        <span class="priority">${taskPriority}</span>
      </div>
    `;

    taskContainer.appendChild(taskElement);
    taskForm.reset();
  });

  // Simple canvas chart (placeholder)
  const ctx = document.getElementById('time-chart').getContext('2d');
  ctx.canvas.height = 200;
  
  // Sample data visualization
  const data = [30, 45, 25];
  const colors = ['#3498db', '#e74c3c', '#2ecc71'];
  const total = data.reduce((a, b) => a + b, 0);
  let startAngle = 0;

  data.forEach((value, index) => {
    const sliceAngle = (2 * Math.PI * value) / total;
    
    ctx.beginPath();
    ctx.fillStyle = colors[index];
    ctx.moveTo(100, 100);
    ctx.arc(100, 100, 80, startAngle, startAngle + sliceAngle);
    ctx.closePath();
    ctx.fill();
    
    startAngle += sliceAngle;
  });
});
